dbprofiles — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- core »

# dbprofiles

`camelot.core.dbprofiles.` `get_countrycode`(profile=None)

  Returns: | two-letter ISO 3166 country code

`camelot.core.dbprofiles.` `get_languagecode`(profile=None)

  Returns: | two-letter ISO 639 language code

`camelot.core.dbprofiles.` `selected_profile_info`()

  Returns: | a dict with the info of the selected profile

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- core »

Comments
blog comments powered by Disqus